#
# spec file for package kured
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#
# nodebuginfo


# Remove stripping of Go binaries.
%define __arch_install_post export NO_BRP_STRIP_DEBUG=true
# Project upstream commit.
%define commit 685f328
Name:           kured
Version:        1.10.2
Release:        1.6
Summary:        Kubernetes daemonset to perform safe automatic node reboots
License:        Apache-2.0
Group:          System/Management
URL:            https://github.com/weaveworks/kured
Source:         %{name}-%{version}.tar.gz
Source1:        vendor.tar.gz
Patch:          systemctl-path.patch
Patch1:         kured-imagePullPolicy.patch
BuildRequires:  fdupes
BuildRequires:  go-go-md2man
BuildRequires:  golang(API) >= 1.17
ExcludeArch:    s390

%description
Kured (KUbernetes REboot Daemon) is a Kubernetes daemonset that
performs safe automatic node reboots when the need to do so is
indicated by the package management system of the underlying OS.

- Watches for the presence of a reboot sentinel e.g. %{_localstatedir}/run/reboot-required

- Utilises a lock in the API server to ensure only one node reboots at a time

- Optionally defers reboots in the presence of active Prometheus alerts

- Cordons & drains worker nodes before reboot, uncordoning them after

%package k8s-yaml
Summary:        Kubernetes yaml file to run kured container
Group:          System/Management
BuildArch:      noarch

%description k8s-yaml
This package contains the yaml file requried to download and run the
kured container in a kubernetes cluster.

%prep
%setup -qa1
%patch -p1
%patch1 -p1

%build
# Build the binary.
export VERSION=%{version}
export COMMIT=%{commit}
go build \
   -mod vendor -buildmode=pie \
   -ldflags "-s -w -X main.gitCommit=$COMMIT -X main.version=$VERSION" \
   -o %{name} cmd/kured/*go

%install
# Install the binary.
install -D -m 0755 %{name} "%{buildroot}/%{_bindir}/%{name}"

# Build the man page from markdown documentation.
go-md2man -in README.md -out %{name}.1

# Install the man page.
install -D -m 0644 %{name}.1 "%{buildroot}/%{_mandir}/man1/%{name}.1"
rm %{name}.1

# Install provided yaml file to download and run the kured container
mkdir -p %{buildroot}%{_datadir}/k8s-yaml/kured
cat kured-rbac.yaml kured-ds.yaml > %{buildroot}%{_datadir}/k8s-yaml/kured/kured.yaml
chmod 644  %{buildroot}%{_datadir}/k8s-yaml/kured/kured.yaml
sed -i -e 's|image: .*|image: registry.opensuse.org/kubic/kured:%{version}|g' %{buildroot}%{_datadir}/k8s-yaml/kured/kured.yaml

%fdupes %{buildroot}

%files
%doc README.md
%license LICENSE
%{_bindir}/%{name}
%{_mandir}/man1/kured.1%{?ext_man}

%files k8s-yaml
%dir %{_datarootdir}/k8s-yaml
%dir %{_datarootdir}/k8s-yaml/kured
%{_datarootdir}/k8s-yaml/kured/kured.yaml

%changelog
* Wed Sep  7 2022 kastl@b1-systems.de
- refresh patch kured-imagePullPolicy.patch
- Update to version 1.10.2:
  * chore: prepare release 1.10.2
  * build(deps): bump helm/chart-testing-action from 2.2.1 to 2.3.0 (#618)
  * build(deps): bump alpine from 3.16.1 to 3.16.2 in /cmd/kured (#617)
  * build(deps): bump github.com/prometheus/client_golang (#616)
  * build(deps): bump nick-invision/retry from 2.8.0 to 2.8.1 (#615)
  * build(deps): bump nick-invision/retry from 2.7.1 to 2.8.0 (#613)
  * build(deps): bump nick-invision/retry from 2.7.0 to 2.7.1
  * build(deps): bump github.com/sirupsen/logrus from 1.8.1 to 1.9.0 (#600)
  * fix: helm chart, use standard labels/best practice (#605)
  * update command line flags in README (#607)
  * build(deps): bump github.com/prometheus/common from 0.35.0 to 0.37.0 (#599)
  * build(deps): bump alpine from 3.16.0 to 3.16.1 in /cmd/kured
  * build(deps): bump github.com/stretchr/testify from 1.7.5 to 1.8.0
  * build(deps): bump github.com/containrrr/shoutrrr from 0.6.0 to 0.6.1
  * ci: address Azure/container-scan regression (#606)
* Fri Jul  1 2022 jkowalczyk@suse.com
- Update to version 1.10.1:
  * prepare release 1.10.1 (#594)
  * Updated helm charts with new message template flag (#589)
  * add CoC file
  * added notification when uncordoning (#587)
  * build(deps): bump github.com/stretchr/testify from 1.7.4 to 1.7.5 (#588)
  * build(deps): bump github.com/stretchr/testify from 1.7.3 to 1.7.4 (#583)
  * build(deps): bump github.com/spf13/cobra from 1.4.0 to 1.5.0 (#584)
  * build(deps): bump gotest.tools/v3 from 3.2.0 to 3.3.0 (#582)
  * build(deps): bump github.com/prometheus/common from 0.34.0 to 0.35.0 (#580)
  * build(deps): bump github.com/stretchr/testify from 1.7.2 to 1.7.3 (#581)
  * build(deps): bump helm/kind-action from 1.2.0 to 1.3.0 (#578)
  * build(deps): bump guyarb/golang-test-annoations from 0.5.1 to 0.6.0 (#577)
- Refresh kured-imagePullPolicy.patch
- Update to BuildRequires: golang(API) >= 1.17 from pinned 1.16
* Thu Jun  9 2022 jkowalczyk@suse.com
- Update to version 1.10.0:
  * Release 1.10.0 preparation (#572)
  * build(deps): bump actions/setup-python from 3 to 4 (#576)
  * build(deps): bump docker/setup-buildx-action from 1 to 2 (#575)
  * build(deps): bump docker/build-push-action from 2 to 3 (#573)
  * build(deps): bump docker/setup-qemu-action from 1 to 2 (#574)
  * Added support for multi-arch image build (#496)
  * Downgrade kind-images for 1.22.x and 1.23.x (#569)
  * build(deps): bump github.com/stretchr/testify from 1.7.1 to 1.7.2 (#571)
  * build(deps): bump github.com/containrrr/shoutrrr from 0.5.3 to 0.6.0 (#570)
  * updated slack-related documentation (#568)
  * build(deps): bump github.com/spf13/viper from 1.11.0 to 1.12.0 (#565)
  * improved documentation covering slack usage (#564)
  * build(deps): bump alpine from 3.15.4 to 3.16.0 in /cmd/kured (#560)
  * tolerate both 1.24+ and prior control plane taints (#562)
  * build: small debug commands for nightly job
  * feat: update kubernetes dependencies (#552)
  * Use clean patch to update node labels. Fixes #553
  * Change after-reboot-node-labels flag to post-reboot-node-labels
  * Add a note about adding multiple node labels
  * Use Errorf instead of Fatalf for node label logging
  * Tidy node labelling code
  * Update readme with node labelling info
  * Add verification for node labelling flags
  * Add node labelling
  * strip unnecessary quotes for notify-url configurations
  * ci: substring suffix inside quotes
  * ci: always use the latest golang patch version
  * build(deps): bump github.com/prometheus/client_golang
  * bump Helm chart version to v2.14.1
  * helm: fix tolerations on 1.24
  * build(deps): bump docker/login-action from 1 to 2
  * helm: ensure kured on 1.24 gets the correct toleration
  * build(deps): bump nick-invision/retry from 2.6.0 to 2.7.0
  * build(deps): bump gotest.tools/v3 from 3.1.0 to 3.2.0
  * build(deps): bump github.com/prometheus/common from 0.33.0 to 0.34.0
  * feat: use go@1.17
  * build(deps): bump github.com/spf13/viper from 1.10.1 to 1.11.0
  * build(deps): bump guyarb/golang-test-annoations from 0.5.0 to 0.5.1
  * build(deps): bump github.com/containrrr/shoutrrr from 0.5.2 to 0.5.3
  * build(deps): bump actions/setup-go from 2 to 3
  * build(deps): bump actions/stale from 4 to 5
  * build(deps): bump alpine from 3.15.3 to 3.15.4 in /cmd/kured
  * fixed yamllint error #521
  * updated README with additional values #521
  * bump chart version to 2.13.0 #521
  * adding value containerSecurityContext to helm chart #521
  * Update README.md
  * build(deps): bump github.com/prometheus/common from 0.32.1 to 0.33.0
  * retry cordon + drain if fail, keep lock
* Wed Mar 30 2022 jkowalczyk@suse.com
- Update to version 1.9.2:
  * update to alpine@3.15.3
  * build(deps): bump alpine from 3.15.1 to 3.15.2 in /cmd/kured
  * build(deps): bump alpine from 3.15.0 to 3.15.1 in /cmd/kured
  * build(deps): bump github.com/stretchr/testify from 1.7.0 to 1.7.1
  * Bump chart version to 2.12.0
  * Mention dynamic Slack parameters
  * Bump chart version
  * Use templating in Slack URL, channel and username
  * build(deps): bump actions/checkout from 2 to 3
  * build(deps): bump helm/chart-testing-action from 2.2.0 to 2.2.1
  * build(deps): bump github.com/spf13/cobra from 1.3.0 to 1.4.0
  * Add Helm values example
  * docs: add sentinel command example for RHEL family
  * build(deps): bump actions/setup-python from 2 to 3
  * build(deps): bump github.com/prometheus/client_golang
  * build(deps): bump github.com/prometheus/client_golang
  * build(deps): bump gotest.tools/v3 from 3.0.3 to 3.1.0
  * Add ability to define ds annotations in helm chart
  * build(deps): bump helm/chart-testing-action from 2.1.0 to 2.2.0
* Fri Jan  7 2022 kastl@b1-systems.de
- Update to version 1.9.1:
  * prepare release 1.9.1
  * small fix in deprecation log messages
  * don't print env variable values in the logs (some are sensitive)
  * prepare 1.9.0
  * Update README.md
  * Add chart configuration for json logging
- rebase patch kured-imagePullPolicy.patch onto 1.9.1
* Fri Jan  7 2022 Johannes Kastl <kastl@b1-systems.de>
- BuildRequire go 1.16 or higher
* Fri Jan  7 2022 kastl@b1-systems.de
- Update to version 1.9.0:
  * build(deps): bump github.com/spf13/viper from 1.10.0 to 1.10.1
  * build(deps): bump github.com/spf13/cobra from 1.2.1 to 1.3.0
  * build(deps): bump github.com/spf13/viper from 1.9.0 to 1.10.0
  * build(deps): bump nick-invision/retry from 2.5.1 to 2.6.0
  * build(deps): bump github.com/spf13/viper from 1.8.1 to 1.9.0
  * update to test against k8s 1.2{1,2,3} kind images
  * ensure go version for tests
  * Update k8s dependencies to 0.22.4
  * update image tag to 1.8.2
  * use sprintf for value in log
  * minor restructure and adding log for flag to env var binding
  * dedup const block
  * address review comments
  * bind environment variables to cobra flags with viper
  * Exclude terminated pods from the blocking mechanism
* Fri Jan  7 2022 kastl@b1-systems.de
- Update to version 1.8.2:
  * fix ghcr.io login
  * Move to GHCR as a backup for Docker Hub
  * build(deps): bump alpine from 3.14 to 3.15.0 in /cmd/kured
  * follow up to #465
  * update docker images too
  * feat: update chart to 2.10.1 w/ 1.8.1 kured image
  * build(deps): bump nick-invision/retry from 2.5.0 to 2.5.1
  * Support json logformatter
  * build(deps): bump github.com/prometheus/common from 0.32.0 to 0.32.1
  * build(deps): bump github.com/prometheus/common from 0.31.1 to 0.32.0
  * build(deps): bump github.com/containrrr/shoutrrr from 0.5.1 to 0.5.2
  * feat: update to 1.8.0
  * feat: add also missing prefer-no-schedule-taint
  * feat: add reboot-sentinel-command to helm-chart
  * fix: correct indent ref: #447
  * docs: updated version table
  * removed notifications/slack package
  * Add reboot-delay CLI argument to docs, manifests and helm charts
  * Add --alert-firing-only parameter to chart
* Fri Jan  7 2022 kastl@b1-systems.de
- Update to version 1.8.0:
  * Revert "[WIP] Add quay.io as second registry"
  * Bump nick-invision/retry from 2.4.1 to 2.5.0
  * doc: some clarification for release-docs
  * Bump github.com/prometheus/common from 0.31.0 to 0.31.1
  * Add jackfrancis to MAINTAINERS
  * build: add quay.io as second registry
  * update to go 1.16 (follow the load of k8s 1.21)
  * build: added k8s@1.22 and dropped k8s@1.19
  * feat: updated to k8s@1.21
  * fix: don't use nil context in drain helper
  * Bump github.com/prometheus/common from 0.30.0 to 0.31.0
  * Bump guyarb/golang-test-annoations from 0.4.0 to 0.5.0
  * Add force-reboot and drain timeouts to chart config and ds
  * fix: do not use array for stale action (#433)
  * Bump github.com/containrrr/shoutrrr from 0.5.0 to 0.5.1
  * build: updated to alpine@3.14
  * Bump github.com/containrrr/shoutrrr from 0.4.4 to 0.5.0
  * Change default updateStrategy to RollingUpdate (#420)
  * Add `reboot-delay` command line argument
  * Add --alert-firing-only parameter to only consider firing alerts
  * Bump github.com/prometheus/common from 0.29.0 to 0.30.0 (#414)
  * Restructuring Prometheus client, added unit-tests to regex-queries active alerts (#386)
  * Added possibility to mount volumes (#407)
  * fix: common default reboot command for code and chart
  * Bump actions/stale from 3.0.19 to 4
  * link to versioned shoutrrr docs
  * Bump github.com/spf13/cobra from 1.1.3 to 1.2.1
  * Bump helm/kind-action from 1.1.0 to 1.2.0
  * our 'good first issue' issue label has no '-', add 'keep'
  * Added rebootCommand values (#394)
  * Bump nick-invision/retry from 2.4.0 to 2.4.1
  * Bump github.com/prometheus/common from 0.25.0 to 0.29.0
  * fix slack deprecation notice
  * Bump helm/chart-testing-action from 2.0.1 to 2.1.0
  * sort parameters alphabetically
  * Add documentation for lockReleaseDelay parameter
  * Add lockReleaseDelay parameter to helm chart
  * doc: update image-version
  * update chart definition to include --notify-url
* Fri Jan  7 2022 Johannes Kastl <kastl@b1-systems.de>
- rebase patch systemctl-path.patch to 1.7.1
* Fri Jan  7 2022 kastl@b1-systems.de
- Update to version 1.7.0:
  * doc: add compat-line for 1.7.0
  * use latest kind
  * Bounce kubernetes testing versions
  * Bump github.com/prometheus/common from 0.24.0 to 0.25.0
  * Bump actions/stale from 3.0.18 to 3.0.19
  * update golang.org/x/crypto - break out of #349
  * Bump github.com/prometheus/common from 0.23.0 to 0.24.0
  * Clarify and simplify tests
  * Bump github.com/prometheus/common from 0.18.0 to 0.23.0
  * docu: update url for ms teams notifications, fixes #362
  * Use stable kind-action
  * Bump github.com/prometheus/client_golang from 1.8.0 to 1.10.0
  * Bump github.com/containrrr/shoutrrr from 0.4.3 to 0.4.4
  * Bump github.com/containrrr/shoutrrr from 0.4.2 to 0.4.3
  * Update kured-ds.yaml
  * Reduce false positives in chart testing
  * Add prometheus export metrics functional testing
  * Add parameter for delaying release of lock
  * update to latest k8s deps of 1.20 branch
  * Expose SkipWaitForDeleteTimeoutSeconds and explicitly return when cordonning fails
  * Update the default drain timeout to be infinite
  * Don't panic if the cordon fails and force-reboot is true
  * Refactor force-drain to be a drain-timeout in general
  * chore: retry daemonset get operations
  * Add force-reboot after force-timeout duration has been exceeded
  * Bump github.com/containrrr/shoutrrr from 0.4.1 to 0.4.2
  * Update deps
  * Add chart-testing target-branch
  * udpate Dev docs to latest
  * Update github actions
  * Change default branch to 'main'.
  * feat: use chart appVersion as default image-tag
  * Fix invoke reboot for custom commands
  * Implement universal notification mechanism
  * Bump guyarb/golang-test-annoations from v0.3.0 to v0.4.0
  * Add go tests
  * Fix the Fatal calls using formatting
  * Add flexible commands parameters
  * Refactor reboot blocks
  * Fix periodic jobs
  * Update the deprecated DeleteLocalData
  * Bouncing go.mod with latest kubernetes packages
  * change comment accordingly
  * extend close-duration for stale issues and prs
  * update chart definition to include --annotate-nodes
  * Adding a MAINTAINERS file
  * update to alpine 3.13
  * Bump github.com/sirupsen/logrus from 1.8.0 to 1.8.1
  * add node annotations
  * always drain before reboot
  * Bump actions/stale from v3.0.17 to v3.0.18
  * Bump actions/stale from v3.0.16 to v3.0.17
  * Bump github.com/sirupsen/logrus from 1.7.0 to 1.8.0
  * Bump github.com/spf13/cobra from 1.1.2 to 1.1.3
  * Bump github.com/spf13/cobra from 1.1.1 to 1.1.2
  * Point to CNCF Code of Conduct
  * Bump actions/stale from v3.0.15 to v3.0.16
  * add podLabels parameter
  * Bump actions/stale from v3.0.14 to v3.0.15
  * change taint config to be disabled by default
  * Update helm chart README using Make
  * Update helm chart
  * remove taint in case the reboot is not needed anymore
  * updated README
  * cache taint state to avoid unnecessary API calls
  * Allow to disable tainting during pending node reboot by setting the taint name to an empty string.
  * fixed type & renamed variable
  * taint node with PreferNoSchedule to prevent receiving (and double draining) additional pods from other rebooting nodes
  * fixed call of log.Fatal instead of log.Fatalf
  * avoid indentations to ease readability
  * Expose the service name and maxUnavailable for rolling updates in the helm chart
* Tue Feb  2 2021 kukuk@suse.com
- Update to version 1.6.1:
  - add additional parameters to override the drain/reboot slack messages
  - rename message template parameters so they are not related to slack
  - Improve coordinated reboot output
  - Add more logs into gates
  - Added support for time wrap in timewindow.Contains
* Tue Nov 24 2020 kukuk@suse.com
- Update to version 1.5.1:
  * rename annotation-ttl to lock-ttl in all places, follow-up to #213
  * Drain: allow pods grace period to terminate
  * Prepare 1.5.1 release
  * Add lint job
  * Make lint happier in pkg folder
  * Make lint happier
  * Remove prom-active-alerts
  * update docs following #210
  * run 'go mod tidy'
  * Replaced --annotationTTL with --lockTTL and made it work correctly
  * Refactor drain/uncordon
  * Remove kubectl exception in container scanning
  * Bump prometheus
  * Use kubectl as library instead of calling from cli
  * fix: Follow DKL-DI-0004 guideline
  * feat: Add security scanning into CI
  * add missing quote - thanks Karan Arora for reporting
  * Bump helm chart version
  * Remove quote for parameter alert-filter-regexp
  * Release helper
* Mon Sep 21 2020 kukuk@suse.com
- Update to version 1.5.0:
  * Prepare 1.5.0 release
  * Bump helm/kind-action from v1.0.0-rc.1 to v1.0.0
  * Bump helm/chart-testing-action from v1.0.0-rc.2 to v1.0.0
  * Add dependabot
  * Prepare for k8s release 1.19 (Aug 25)
* Fri Aug 14 2020 kukuk@suse.com
- Update to version 1.4.5:
  * document how releases are town wrt Helm bits
  * bump versions for 1.4.5 release
  * Use nindent, not indent
  * chart: update readme
  * Bump chart version
  * Add missing 'end'
  * Chart: Support extraEnvVars
  * update install instructions to use latest
  * update chart version
  * Prep for 1.4.4 release
  * bump and fix
  * split matchLabels template
  * restructured and improved service
* Tue Jun 30 2020 dmueller@suse.com
- Update to version 1.4.3:
  * bump and fix
  * split matchLabels template
  * restructured and improved service
  * bumped kured to upcoming 1.4.3 fixed servicemonitor indent fixed quotes for arguments
  * update things for 1.4.2 release
  * Use GITHUB_TOKEN for releasing chart
  * make markdownlint happier
  * update version
  * prepare chart-release for 1.4.1
  * Revert #139
- use obs-service for regenerating vendor.tar.gz
* Tue Jun 30 2020 Thorsten Kukuk <kukuk@suse.com>
- Update to version 1.4.2
  - Adding --annotation-ttl for automatic unlock
- Refresh vendor.tar.xz
* Mon May 18 2020 Thorsten Kukuk <kukuk@suse.com>
- kured-imagePullPolicy.patch: always update the image
* Sun May 17 2020 Thorsten Kukuk <kukuk@suse.com>
- systemctl-path.patch: last systemd update removed symlinks
  from /bin ...
* Mon May 11 2020 Thorsten Kukuk <kukuk@suse.com>
- Update to version 1.4.0
  - Updated kubectl, client-go, etc to k8s 1.17 (#127, #135)
  - Update to go 1.13 (#130)
  - print node id when commanding reboot (#134)
* Wed Apr 22 2020 Dominique Leuenberger <dimstar@opensuse.org>
- Fix build-dependency: we require golang(API) 1.12, not the exact
  go package version 1.12.
* Mon Mar  2 2020 Thorsten Kukuk <kukuk@suse.com>
- Update to version 1.3.0
  - Update k8s client tools to 1.15.x
  - Ad Slack channel name configuration
  - Add reboot window
- Obsoletes k8s-1.14.diff
- Remove kured-telemetrics.patch, chances that upstream accepts
  any third party code are nearly zero.
- Update vendor.tar.xz
* Mon Jun 24 2019 kukuk@suse.de
- k8s-1.14.diff: kubernetes 1.14.1 support from git
* Wed Jun  5 2019 kukuk@suse.de
- Fix path to image in manifest
* Wed May 22 2019 kukuk@suse.de
- Update to version 1.2.0
  - support newer kubernetes versions
- Adjust kured-telemetrics.patch
- Update vendor.tar.gz with recent versions
* Sat Apr  6 2019 kukuk@suse.de
- Enable building on s390x
* Thu Mar 28 2019 Jan Engelhardt <jengelh@inai.de>
- Combine %%setup calls.
* Thu Mar 28 2019 kukuk@suse.de
- kured-telemetrics.patch: add hooks for telemetrics data
- Renamed kured-yaml to kured-k8s-yaml to follow new policy
* Thu Feb 28 2019 kukuk@suse.de
- Change path in yaml file to point to official container image
* Fri Jan 18 2019 kukuk@suse.de
- Create a correct yaml file to download and run the kured container
  image in a kubernetes cluster
- Create new subpackage containing only the yaml file, so that
  people using the container don't need to install the not needed
  full package.
* Thu Nov 15 2018 Jeff Kowalczyk <jkowalczyk@suse.com>
- Update to kured 1.1.0
- Upstream bumped dependency on go1.10 via dependency k8s.io/client-go 0.9.0
  https://github.com/kubernetes/client-go
- Provide dependencies in separate vendor.tar.gz
- Improvements
  * RBAC support
  * Use the systemctl in the host mount namespace to effect reboots, reducing
    image size and eliminating the potential for incompatibility
  * Notify Slack on drain in addition to reboot
  * Pass through log output from invoked kubectl commands
  * Tolerate NoSchedule taint on node-role.kubernetes.io/master
  * Fixed reversal of daemonset name/namespace arguments and comments in the
    manifest
- Kubernetes Version Compatibility
  * The daemon image contains a 1.12.x k8s.io/client-go and kubectl binary for
    the purposes of maintaining the lock and draining worker nodes. Kubernetes
    aims to provide forwards & backwards compatibility of one minor version
    between client and server, so this should work on 1.11.x and 1.13.x.
  * Tested in minikube on 1.11.4, 1.12.1 & 1.13.0-alpha.2
  * Tested in production on 1.11.2 & 1.12.2
* Thu Sep 13 2018 jkowalczyk@suse.com
- Remove hardcoded GOARCH=amd64 and GOOS=linux
- Revise go build arg -ldflags and add -buildmode=pie
- Together these fix rpmlint warnings:
  * position-independent-executable-suggested
  * statically-linked-binary
- Upstream kured project code imports package as 'context'. Bump BuildRequires
  to go1.7 wherein import path for package context graduates from
  'golang.org/x/net/context' to the standard library as 'context'.
  https://golang.org/doc/go1.7#context
- Bump release number
* Wed Sep 12 2018 jkowalczyk@suse.com
- Initial packaging of upstream master branch @ 5731b98 (tagged 1.0.0 + 24)
- Include 24 commits since release 1.0.0 updating kubernetes version support
- Dependency sources vendored via dep ensure per upstream build instructions
- Man page converted from README.md, some HTML formatting artifacts present
- rpmlint warning: position-independent-executable-suggested
  * go1.11 currently in review status supports option -buildmode=pie
- rpmlint warning: statically-linked-binary
  * Go binaries are generally statically linked
